<?php
/**
 * @file
 * Administration code for the vdm_google_tag module.
 */

 /**
 * Admin settings form for vdm_google_tag module
 */
function vdm_google_tag_settings_form(){
  $form = array();

  $form['vdm_google_tag_gtm_tag'] = array(
    '#type' => 'textfield',
    '#title' => t('Google Tag Manager Token'),
    '#default_value' => variable_get_value('vdm_google_tag_gtm_tag'),
    '#required' => TRUE
  );

  $form['vdm_google_tag_no_admin_paths'] = array(
    '#type' => 'checkbox',
    '#title' => t('Do not load on administrative paths'),
    '#default_value' => variable_get_value('vdm_google_tag_no_admin_paths'),
    '#required' => FALSE
  );

  $form['vdm_google_tag_anonymous_only'] = array(
    '#type' => 'checkbox',
    '#title' => t('Do not load for connected users'),
    '#default_value' => variable_get_value('vdm_google_tag_anonymous_only'),
    '#required' => FALSE
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
  );

  return $form;
}

/**
 * vdm_google_tag_settings_form_submit
 * 
 * Loads the snippet files if conditions are met
 * Sets the module variables and reports
 * 
 * @param form + form_state, obtained from main form
 * @return nothing
 */

function vdm_google_tag_settings_form_submit($form, &$form_state) {

    $paths = _get_file_paths();
    $created = FALSE;
    $written = FALSE;

    // Create and set variables from variable names
    $module_variables = _get_module_variables();
    foreach ($module_variables as $var) {
      ${$var} = isset($form_state['values'][$var]) ? $form_state['values'][$var] : FALSE;
      variable_set($var, ${$var});
    }

    if($vdm_google_tag_gtm_tag) {

        // Create the includes directory as needed
        if (!is_dir($paths['includes'])) {
          try {
            mkdir(DRUPAL_ROOT . '/' . $paths['includes']);
            drupal_set_message('The includes directory was created.');
          } catch (\Throwable $th) {
            drupal_set_message('Could not create the includes, check the watchdog to find out why');
            watchdog(
              'vdm_google_tag',
              'Error creating the includes directory in  %function() <pre>@throw</pre>',
              array(
                '%function' => __FUNCTION__, 
                '@throw' => $th
              ),
              WATCHDOG_ERROR
            );
          }
        }

        // Write new includes files with custom token
        foreach ($paths['files'] as $type => $file) {

            $source = $paths['templates'] . $file;
            $destination = $paths['includes'] . $file;

            // Create the includes files as needed
            if (!file_exists($destination)) {
                touch($destination);
                $created = true;
            }

            // Replace token and save
            $source_contents = file_get_contents($source);
            $destination_contents = str_replace("[GOOGLE_TAG_VDM_PLACEHOLDER]", $vdm_google_tag_gtm_tag, $source_contents);

            file_put_contents($destination, $destination_contents);
            $written = TRUE;
        }

        // Set status messages
        if($written) {
          if(!$created) {
            drupal_set_message('Snippet files were saved with token ' . $vdm_google_tag_gtm_tag . '.' );
          } else {
            drupal_set_message('Snippet files were created and were saved with token ' . $vdm_google_tag_gtm_tag . '.' );
          }
        } else {
          drupal_set_message('Snippet files could not be created, check with the module developper.' );
        }
    }
}